@@ -27,7 +27,7 @@ module Facter
     include Comparable
     include Enumerable
 
-    FACTERVERSION = '1.5.7'
+    FACTERVERSION = '1.5.9'
     # = Facter
     # Functions as a hash of 'facts' you might care about about your
     # system, such as mac address, IP address, Video card, etc.
@@ -48,6 +48,7 @@ module Facter
     GREEN = "[0;32m"
     RESET = "[0m"
     @@debug = 0
+    @@timing = 0
 
     # module methods
 
@@ -68,11 +69,24 @@ module Facter
         if string.nil?
             return
         end
-        if @@debug != 0
+        if self.debugging?
             puts GREEN + string + RESET
         end
     end
 
+    def self.debugging?
+        @@debug != 0
+    end
+
+    # show the timing information
+    def self.show_time(string)
+        puts "#{GREEN}#{string}#{RESET}" if string and Facter.timing?
+    end
+
+    def self.timing?
+        @@timing != 0
+    end
+
     # Return a fact object by name.  If you use this, you still have to call
     # 'value' on it to retrieve the actual value.
     def self.[](name)
@@ -173,6 +187,30 @@ module Facter
         end
     end
 
+    # Set timing on or off.
+    def self.timing(bit)
+        if bit
+            case bit
+            when TrueClass; @@timing = 1
+            when Fixnum
+                if bit > 0
+                    @@timing = 1
+                else
+                    @@timing = 0
+                end
+            end
+        else
+            @@timing = 0
+        end
+    end
+
+    def self.warn(msg)
+        if Facter.debugging? and msg and not msg.empty?
+            msg = [msg] unless msg.respond_to? :each
+            msg.each { |line| Kernel.warn line }
+        end
+    end
+
     # Remove them all.
     def self.reset
         @collection = nil
