@@ -7,7 +7,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet addr:([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -19,7 +19,7 @@ Facter.add(:ipaddress) do
 end
 
 Facter.add(:ipaddress) do
-    confine :kernel => %w{FreeBSD OpenBSD}
+    confine :kernel => %w{FreeBSD OpenBSD Darwin}
     setcode do
         ip = nil
         output = %x{/sbin/ifconfig}
@@ -27,7 +27,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -47,38 +47,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
-                    ip = tmp
-                    break
-                end
-            end
-        }
-
-        ip
-    end
-end
-
-Facter.add(:ipaddress) do
-    confine :kernel => %w{darwin}
-    setcode do
-        ip = nil
-        iface = ""
-        output = %x{/usr/sbin/netstat -rn}
-        if output =~ /^default\s*\S*\s*\S*\s*\S*\s*\S*\s*(\S*).*/
-          iface = $1
-        else
-          warn "Could not find a default route. Using first non-loopback interface"
-        end
-        if(iface != "")
-          output = %x{/sbin/ifconfig #{iface}}
-        else
-          output = %x{/sbin/ifconfig}
-        end
-
-        output.split(/^\S/).each { |str|
-            if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
-                tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./ or tmp == "0.0.0.0"
                     ip = tmp
                     break
                 end
@@ -98,7 +67,7 @@ Facter.add(:ipaddress) do
         output.split(/^\S/).each { |str|
             if str =~ /inet ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
                 tmp = $1
-                unless tmp =~ /127\./
+                unless tmp =~ /^127\./
                     ip = tmp
                     break
                 end
@@ -112,29 +81,26 @@ end
 Facter.add(:ipaddress) do
     confine :kernel => %w{windows}
     setcode do
-        ip = nil
-        output = %x{ipconfig}
-
-        output.split(/^\S/).each { |str|
-            if str =~ /IP Address.*: ([0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)/
-                tmp = $1
-                unless tmp =~ /127\./
-                    ip = tmp
-                    break
-                end
-            end
-        }
-        ip
+        require 'socket'
+        IPSocket.getaddress(Socket.gethostname)
     end
 end
 
 Facter.add(:ipaddress, :ldapname => "iphostnumber", :timeout => 2) do
     setcode do
-        require 'resolv'
-
+        if Facter.value(:kernel) == 'windows'
+            require 'win32/resolv'
+        else
+            require 'resolv'
+        end
+        
         begin
             if hostname = Facter.value(:hostname)
-                ip = Resolv.getaddress(hostname)
+                if Facter.value(:kernel) == 'windows'
+                    ip = Win32::Resolv.get_resolv_info.last[0]
+                else
+                    ip = Resolv.getaddress(hostname)                
+                end
                 unless ip == "127.0.0.1"
                     ip
                 end
