@@ -20,15 +20,15 @@
    "LSBDistCodeName"    => %r{^Codename:\t(.*)$}
 }.each do |fact, pattern|
     Facter.add(fact) do
-        confine :kernel => :linux
+        confine :kernel => [ :linux, :"gnu/kfreebsd" ]
         setcode do
-            unless defined?(@@lsbdata) and defined?(@@lsbtime) and (Time.now.to_i - @@lsbtime.to_i < 5)
+            unless defined?(lsbdata) and defined?(lsbtime) and (Time.now.to_i - lsbtime.to_i < 5)
                 type = nil
-                @@lsbtime = Time.now
-                @@lsbdata = Facter::Util::Resolution.exec('lsb_release -a 2>/dev/null')
+                lsbtime = Time.now
+                lsbdata = Facter::Util::Resolution.exec('lsb_release -a 2>/dev/null')
             end
 
-            if pattern.match(@@lsbdata)
+            if pattern.match(lsbdata)
                 $1
             else
                 nil
