@@ -1,5 +1,7 @@
+require 'facter/util/macaddress'
+
 Facter.add(:macaddress) do
-    confine :operatingsystem => %w{Solaris Linux Fedora RedHat CentOS SuSE SLES Debian Gentoo Ubuntu OEL OVS}
+    confine :operatingsystem => %w{Solaris Linux Fedora RedHat CentOS SuSE SLES Debian Gentoo Ubuntu OEL OVS GNU/kFreeBSD}
     setcode do
         ether = []
         output = %x{/sbin/ifconfig -a}
@@ -26,19 +28,7 @@ end
 
 Facter.add(:macaddress) do
     confine :kernel => :darwin
-    setcode do
-        ether = nil
-        output = %x{/sbin/ifconfig}
-
-        output.split(/^\S/).each do |str|
-            if str =~ /10baseT/ # we're wired
-                str =~ /ether (\w\w:\w\w:\w\w:\w\w:\w\w:\w\w)/
-                ether = $1
-            end
-        end
-
-        ether
-    end
+    setcode { Facter::Util::Macaddress::Darwin.macaddress }
 end
 
 Facter.add(:macaddress) do
