@@ -20,16 +20,26 @@ Facter.add(:operatingsystem) do
             "Mandriva"
         elsif FileTest.exists?("/etc/mandrake-release")
             "Mandrake"
-	elsif FileTest.exists?("/etc/arch-release")
-	    "Archlinux"
+        elsif FileTest.exists?("/etc/meego-release")
+            "MeeGo"
+        elsif FileTest.exists?("/etc/arch-release")
+            "Archlinux"
         elsif FileTest.exists?("/etc/enterprise-release")
-            "OEL"
-        elsif FileTest.exists?("/etc/ovs-release")
-            "OVS"
+            if FileTest.exists?("/etc/ovs-release")
+                "OVS"
+            else
+                "OEL"
+            end
+        elsif FileTest.exists?("/etc/arch-release")
+            "Arch"
+        elsif FileTest.exists?("/etc/vmware-release")
+            "VMWareESX"
         elsif FileTest.exists?("/etc/redhat-release")
             txt = File.read("/etc/redhat-release")
             if txt =~ /centos/i
                 "CentOS"
+            elsif txt =~ /scientific/i 
+                "Scientific"
             else
                 "RedHat"
             end
@@ -37,15 +47,30 @@ Facter.add(:operatingsystem) do
             txt = File.read("/etc/SuSE-release")
             if txt =~ /^SUSE LINUX Enterprise Server/i
                 "SLES"
-	    elsif txt =~ /^openSUSE/i
-		"OpenSuSE"
+            elsif txt =~ /^SUSE LINUX Enterprise Desktop/i
+                "SLED"
+            elsif txt =~ /^openSUSE/i
+                "OpenSuSE"
             else
                 "SuSE"
             end
+        elsif FileTest.exists?("/etc/bluewhite64-version")
+            "Bluewhite64"
+        elsif FileTest.exists?("/etc/slamd64-version")
+            "Slamd64"
+        elsif FileTest.exists?("/etc/slackware-version")
+            "Slackware"
         end
     end
 end
 
+Facter.add(:operatingsystem) do
+    confine :kernel => "VMkernel"
+    setcode do
+        "ESXi"
+    end
+end
+
 Facter.add(:operatingsystem) do
     # Default to just returning the kernel as the operating system
     setcode do Facter[:kernel].value end
